﻿using C1.WPF.DataGrid;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace DataGridGroupHeader
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public ObservableCollection<UserItem> UserItemSource { get; set; }
        public static List<DataGridGroupRow> GroupRows = new List<DataGridGroupRow>();

        public MainWindow()
        {
            InitializeComponent();

            // Initialize and populate your data source
            UserItemSource = new ObservableCollection<UserItem>
            {
                new UserItem { Group = "Group1", SubGroup = "SubGroup 1", Name = "Item 1", Value = "Value1" },
                new UserItem { Group = "Group1", SubGroup = "SubGroup 2", Name = "Item 2", Value = "Value2" },
                new UserItem { Group = "Group2", SubGroup = "SubGroup 1", Name = "Item 3", Value = "Value3" },
                new UserItem { Group = "Group1", SubGroup = "SubGroup 1", Name = "Item 4", Value = "Value4" },
                new UserItem { Group = "Group1", SubGroup = "SubGroup 1", Name = "Item 5", Value = "Value5" },
                new UserItem { Group = "Group2", SubGroup = "SubGroup 1", Name = "Item 6", Value = "Value6" },
                new UserItem { Group = "Group2", SubGroup = "SubGroup 2", Name = "Item 7", Value = "Value7" },
                new UserItem { Group = "Group1", SubGroup = "SubGroup 2", Name = "Item 8", Value = "Value8" },
                new UserItem { Group = "Group2", SubGroup = "SubGroup 2", Name = "Item 9", Value = "Value9" },
                // Add more items as needed
            };

            // Set the data context to the main window
            DataContext = this;
            dataGrid.Loaded += DataGrid_Loaded;
            dataGrid.LoadedRowHeaderPresenter += DataGrid_LoadedRowHeaderPresenter;
            dataGrid.MouseWheel += DataGrid_MouseWheel;
        }

        private void DataGrid_MouseWheel(object sender, MouseWheelEventArgs e)
        {
            dataGrid.Refresh();
        }

        private void DataGrid_LoadedRowHeaderPresenter(object sender, C1.WPF.DataGrid.DataGridRowEventArgs e)
        {
            var grpRow = e.Row as DataGridGroupRow;
            if(grpRow != null && GroupRows.Contains(grpRow))
            {
                var rowPresenter = grpRow.Presenter as DataGridGroupRowPresenter;
                var textblock = rowPresenter.GroupContent as TextBlock;
                textblock.Text = textblock.Text + ": Additional data";
            }
        }

        private void DataGrid_Loaded(object sender, RoutedEventArgs e)
        {
            foreach(var row in (sender as C1DataGrid).Rows)
            {
                if(row is DataGridGroupRow)
                {
                    (row as DataGridGroupRow).GroupRowsVisibilityChanged += MainWindow_GroupRowsVisibilityChanged;
                }
            }
        }

        private void MainWindow_GroupRowsVisibilityChanged(object sender, C1.WPF.PropertyChangedEventArgs<Visibility> e)
        {
            var grpRow  = sender as DataGridGroupRow;
            var rowPresenter = grpRow.Presenter as DataGridGroupRowPresenter;
            var textblock = rowPresenter.GroupContent as TextBlock;

            if (e.NewValue == Visibility.Collapsed)
            {
                GroupRows.Add(grpRow);
                textblock.Text = textblock.Text + ": Additional data";
            }
            else
            {
                GroupRows.Remove(grpRow);
                textblock.Text = textblock.Text.Substring(0, textblock.Text.IndexOf(':'));
            }
        }
    }

    public class UserItem : INotifyPropertyChanged
    {
        private string _group;
        public string Group
        {
            get { return _group; }
            set
            {
                if (_group != value)
                {
                    _group = value;
                    OnPropertyChanged(nameof(Group));
                }
            }
        }

        private string _subGroup;
        public string SubGroup
        {
            get { return _subGroup; }
            set
            {
                if (_subGroup != value)
                {
                    _subGroup = value;
                    OnPropertyChanged(nameof(SubGroup));
                }
            }
        }

        private string _name;
        public string Name
        {
            get { return _name; }
            set
            {
                if (_name != value)
                {
                    _name = value;
                    OnPropertyChanged(nameof(Name));
                }
            }
        }

        private string _value;
        public string Value
        {
            get { return _value; }
            set
            {
                if (_value != value)
                {
                    _value = value;
                    OnPropertyChanged(nameof(Value));
                }
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged(string propertyName)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
